@@ -72,7 +72,7 @@ class RpcException(Exception):
 class Request(dict):
     """A request object that wraps params and allows async return
     """
-    def __init__(self, plugin: 'Plugin', req_id: Optional[int], method: str,
+    def __init__(self, plugin: 'Plugin', req_id: Optional[str], method: str,
                  params: Any, background: bool = False):
         self.method = method
         self.params = params
@@ -607,17 +607,25 @@ class Plugin(object):
 
     def _exec_func(self, func: Callable[..., Any],
                    request: Request) -> JSONType:
+        # By default, any RPC calls this makes will have JSON id prefixed by incoming id.
+        if self.rpc:
+            self.rpc.cmdprefix = request.id
         params = request.params
         if isinstance(params, list):
             ba = self._bind_pos(func, params, request)
-            return func(*ba.args, **ba.kwargs)
+            ret = func(*ba.args, **ba.kwargs)
         elif isinstance(params, dict):
             ba = self._bind_kwargs(func, params, request)
-            return func(*ba.args, **ba.kwargs)
+            ret = func(*ba.args, **ba.kwargs)
         else:
+            if self.rpc:
+                self.rpc.cmdprefix = None
             raise TypeError(
                 "Parameters to function call must be either a dict or a list."
             )
+        if self.rpc:
+            self.rpc.cmdprefix = None
+        return ret
 
     def _dispatch_request(self, request: Request) -> None:
         name = request.method
@@ -700,13 +708,9 @@ class Plugin(object):
         request.progress(progress, progress_total, stage, stage_total)
 
     def _parse_request(self, jsrequest: Dict[str, JSONType]) -> Request:
-        i = jsrequest.get('id', None)
-        if not isinstance(i, int) and i is not None:
-            raise ValueError('Non-integer request id "{i}"'.format(i=i))
-
         request = Request(
             plugin=self,
-            req_id=i,
+            req_id=jsrequest.get('id', None),
             method=str(jsrequest['method']),
             params=jsrequest['params'],
             background=False,
